package com.akamai.ampaudiodemo;

import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;

import java.util.Stack;


public class MainActivity extends ActionBarActivity implements IPlayerEventsListener {

    public Stack<String> streams;

    public VideoPlayerContainer mVideoContainer;

    public VideoPlayerView mVideoView;

    private Button btnSwitch;

    private final static String TAG = MainActivity.class.getSimpleName();

    private final static String LICENSE = "QpJHv679nYOslfq_CIn2a6EGd8VIHe_3VXnppglKToMhdPyUrsIkOVAMU4RHKjfDnICOuuIkFHoLgaZ5vnAHaA==";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        streams = initStreams();

        // Get a reference to the VideoContainer object
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);

        // Set the decoding mode used by the Android SDK video control
        mVideoContainer.setMode(VideoPlayerContainer.MODE_AUTOMATIC);
        Log.i(TAG, "MODE: " + mVideoContainer.getMode());

        // Get a reference to the VideoView object
        mVideoView = mVideoContainer.getAudioPlayer();

        // Set the IPlayerEventsListener implementation as the event listener
        mVideoView.setEventsListener(this);

        // Set your license
        mVideoView.setLicense(LICENSE);
        Log.i(TAG, "VERSION: " + VideoPlayerView.VERSION);

        btnSwitch = (Button) findViewById(R.id.btnSwitch);

        btnSwitch.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mVideoView.isPlaying()) {
                    mVideoView.stop();
                }
                if (streams.size() == 0) {
                    Toast.makeText(MainActivity.this, "Reloading streams!", Toast.LENGTH_SHORT).show();
                    streams = initStreams();
                }
                String stream = streams.pop();
                mVideoView.playAudioUrl(stream);
                Toast.makeText(MainActivity.this, stream, Toast.LENGTH_SHORT).show();
            }
        });
    }

    private Stack<String> initStreams() {
        Stack<String> stack = new Stack<>();

        stack.push("http://raceview.b.nascar.com/hls_audio_testfeeds/whoknows/prog_index.m3u8");
        stack.push("http://raceview.b.nascar.com/hls_audio_testfeeds/perfidia/prog_index.m3u8");
        stack.push("http://raceview.b.nascar.com/hls_audio_testfeeds/karmapolice/prog_index.m3u8");
        stack.push("http://raceview.b.nascar.com/hls_audio_testfeeds/Fontana/radio/prog_index.m3u8");
        stack.push("http://nrkradio-f.akamaihd.net/i/p3_0@4275/master.m3u8");
        stack.push("http://radio_cjrx-lh.akamaihd.net/i/LET1067_1@190221/master.m3u8");
        stack.push("http://radio_cftr-lh.akamaihd.net/i/TOR680_1@176946/master.m3u8");
        stack.push("http://radio_cjqm-lh.akamaihd.net/i/SAU1043_1@192252/master.m3u8");
        stack.push("http://radio_chym-lh.akamaihd.net/i/KIT967_1@183249/master.m3u8");
        stack.push("http://ipv.wdr.de/metafiles/radio/wdr3/hls/wdr3.m3u8");
        stack.push("http://yleuni-f.akamaihd.net/i/yleliveradiohd_1@113878/master.m3u8?hdnea=st=1411552251~exp=1411552551~acl=/i/yleliveradiohd_1@113878*~hmac=f3d15989e872471e5e73fd5c6d8673e5fb50ae044a35621b0bddd569f92e9e64");
        stack.push("http://nordond32a-f.akamaihd.net/i/wo/open/74/745f4fc72b4c59db2dabb4f997e4c5e7c09d1fa7/d19b9a3a-d3e0-45fc-9082-c150041469ee_,64,192,.mp4.csmil/master.m3u8");
        stack.push("http://nrkradio-f.akamaihd.net/i/p2_0@4274/master.m3u8");

        return stack;
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onPlayerEvent(int i) {
        Log.d(TAG, "onPlayerEvent: " + i);
        if (i == PLAYER_EVENT_TYPE_POSITION_UPDATE) {
                Log.d(TAG, "onPlayerEvent: POS: " + mVideoView.getTimePosition());
                Log.d(TAG, "onPlayerEvent: BITRATE: " + mVideoView.getCurrentBitrate());
        }

        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int i, int i2, int i3) {
        return false;
    }
}
